SGTPy is an open-source python package of SAFT-VR-Mie and SAFT-Gamma-Mie Equations of State (EOS).
SGTPy allows to work with pure fluids and fluid mixtures, additionally the fluids
can be modeled considering association, cross-association and polar contributions.
SGTPy was built on top of phasepy's phase equilibrium and Square
Gradient Theory (SGT) functions. These functions were updated to speed-up
calculations of associative mixtures.

SGTPy relies on Numpy, SciPy and PhasePy.
